const locale = {
    "(area: {measure})": "(svæði: {measure})",
    "(length: {measure})": "(lengd: {measure})",
    "# one hash for main heading": "# eitt myllumerki fyrir aðalfyrirsögn",
    "## two hashes for second heading": "## tvö myllumerki fyrir aðra fyrirsögn",
    "### three hashes for third heading": "### þrjú myllumerki fyrir þriðju fyrirsögn",
    "**double star for bold**": "**tvöföld stjarna/margföldun fyrir feitletrað**",
    "*single star for italic*": "*einföld stjarna/margföldun fyrir skáletrað*",
    "--- for a horizontal rule": "--- gefur lárétt þverstrik",
    "1 day": "1 dagur",
    "1 hour": "1 klukkustund",
    "5 min": "5 mín",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Kommu-aðgreindur listi með tölum sem skilgreina strikamynstur. Til dæmis: '5, 10, 15'.",
    "About": "Um hugbúnaðinn",
    "Action not allowed :(": "Þessi aðgerð er ekki leyfð :(",
    "Activate slideshow mode": "Virkja skyggnusýningarham",
    "Add a layer": "Bæta við þekju",
    "Add a line to the current multi": "Bæta línu við fyrirliggjandi hóp",
    "Add a polygon to the current multi": "Bæta marghyrningi við fyrirliggjandi hóp",
    "Add image URL": "Bæta við slóð á mynd",
    "Advanced actions": "Ítarlegri aðgerðir",
    "Advanced properties": "Ítarlegir eiginleikar",
    "All data and settings of the map": "All data and settings of the map",
    "All properties are imported.": "Öll eigindi voru flutt inn.",
    "Allow interactions": "Leyfa gagnvirkni",
    "Allow scroll wheel zoom?": "Leyfa aðdrátt með skrunhjóli?",
    "always": "alltaf",
    "Animated transitions": "Millifærslur með hreyfingu",
    "Are you sure you want to clone this map and all its datalayers?": "Ertu viss um að þú viljir klóna þetta kort og allar gagnaþekjur þess?",
    "Are you sure you want to delete this map?": "Ertu viss um að þú viljir eyða þessu korti?",
    "Are you sure you want to restore this version?": "Ertu viss um að vilja endurheimta þessa útgáfu?",
    "Attach the map to my account": "Tengja kortið við notandaaðganginn minn",
    "attribution": "tilvísun í höfund/a",
    "Auto": "Sjálfvirkt",
    "Automatic": "Sjálfvirkt",
    "Autostart when map is loaded": "Sjálfræsa þegar korti er hlaðið inn",
    "Back to preview": "Til baka í forskoðun",
    "Background overlay url": "Background overlay url",
    "Ball": "Kúla",
    "Bring feature to center": "Færa fitju að miðju",
    "Browse data": "Skoða gögn",
    "by": "eftir",
    "Cache proxied request": "Setja milliþjónabeiðnir í skyndiminni",
    "Caption": "Skýringatexti",
    "Center map on your location": "Miðjusetja kortið á staðsetningu þína",
    "Change tilelayers": "Skipta um kortatíglaþekjur",
    "Change": "Breyta",
    "Choose the data format": "Veldu gagnasnið",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Choropleth": "Choropleth",
    "Circle": "Hringur",
    "clear": "hreinsa",
    "Click last point to finish shape": "Smelltu á síðasta punktinn til að ljúka lögun",
    "Click to add a marker": "Smella til að bæta við kortamerki",
    "Click to continue drawing": "Smelltu til að halda áfram að teikna",
    "Click to start drawing a line": "Smelltu til að byrja að teikna línu",
    "Click to start drawing a polygon": "Smelltu til að byrja að teikna fláka (marghyrning)",
    "Clone of {name}": "Klónað afrit af {name}",
    "Clone this feature": "Klóna þessa fitju",
    "Clone this map": "Klóna þetta landakort",
    "Clone": "Klóna",
    "Close": "Loka",
    "Clustered": "Í klösum",
    "Clustering radius": "Radíus klasa",
    "collapsed": "samfallið",
    "color": "litur",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Gildi aðgreind með kommu, dálkmerki (tab) eða semíkommu. Miðað við SRS hnattviðmið WGS84. Einungis punktalaganir (geometries) eru fluttar inn. Við innflutning er skoðað í fyrirsögnum dálka hvort minnst sé á «lat» eða «lon» í byrjun fyrirsagna, óháð há-/lágstöfum. Allir aðrir dálkar eru fluttir inn sem eigindi.",
    "Congratulations, your map has been created!": "Til hamingju, það tókst að útbúa landakortið þitt!",
    "Continue line": "Halda áfram með línu",
    "Coordinates": "Hnit",
    "copy": "copy",
    "Credits": "Framlög",
    "Current map view": "Núverandi kortasýn",
    "Current view instead of default map view?": "Fyrirliggjandi sýn í stað sjálfgefinnar kortasýnar?",
    "Custom background": "Sérsniðinn bakgrunnur",
    "Custom overlay": "Sérsniðið yfirlag",
    "dash array": "strikafylki",
    "Data is browsable": "Gögn eru vafranleg",
    "Datalayers": "Gagnaþekjur",
    "Default interaction options": "Sjálfgefnir valkostir gagnvirkni",
    "Default properties": "Sjálfgefnir eiginleikar",
    "Default shape properties": "Sjálfgefnir eiginleikar lögunar",
    "Default view": "Sjálfgefin sýn",
    "Default zoom level": "Sjálfgefið aðdráttarstig",
    "Default": "Sjálfgefið",
    "Default: name": "Sjálfgefið: nafn",
    "Define link to open in a new window on polygon click.": "Skilgreindu tengil til að opna í nýjum glugga þegar smellt er á marghyrning.",
    "define": "skilgreina",
    "Delay between two transitions when in play mode": "Hlé milli tveggja millifærslna í afspilunarham",
    "Delete layer": "Eyða þekju",
    "Delete this feature": "Eyða þessari fitju",
    "Delete this shape": "Eyða þessari lögun",
    "Delete this vertex (Alt+Click)": "Eyða þessum brotpunkti (Alt+Smella)",
    "Delete": "Eyða",
    "description": "lýsing",
    "Direct link": "Beinn tengill",
    "Directions from here": "Leiðir héðan",
    "Display label": "Birta skýringu",
    "Display measure": "Birta mælingar",
    "display name": "birtingarnafn",
    "Display on load": "Birta við innhleðslu",
    "Display the control to open OpenStreetMap editor": "Birta hnapp til að opna OpenStreetMap-ritill",
    "Display the embed control": "Birta hnapp fyrir ígræðslukóða",
    "Display the fullscreen control": "Birta hnapp fyrir skjáfylli",
    "Display the locate control": "Birta staðsetningarhnapp",
    "Display the measure control": "Birta mælihnapp",
    "Display the search control": "Birta leitarhnapp",
    "Display the tile layers control": "Birta hnapp fyrir kortatíglaþekjur",
    "Display the zoom control": "Birta aðdráttarhnapp",
    "Do you want to display a caption bar?": "Viltu birta skjástiku með skýringatexta?",
    "Do you want to display a minimap?": "Viltu birta yfirlitskort?",
    "Do you want to display a panel on load?": "Viltu birta hliðarspjald við innhleðslu?",
    "Do you want to display caption menus?": "Viltu birta valmyndir með skýringatexta?",
    "Do you want to display popup footer?": "Viltu birta síðufót sem sprettglugga?",
    "Do you want to display the scale control?": "Viltu birta kvarðahnapp?",
    "Do you want to display the «more» control?": "Viltu birta hnapp fyrir «meira»?",
    "Download": "Sækja",
    "Drag to reorder": "Draga til að endurraða",
    "Draw a marker": "Teikna kortamerki",
    "Draw a polygon": "Teikna fláka (marghyrning)",
    "Draw a polyline": "Teikna fjölpunktalínu (polyline)",
    "Drawing": "Teikning",
    "Drop": "Dropi",
    "Dynamic properties": "Breytilegir eiginleikar",
    "Dynamic": "Breytilegt",
    "Edit feature's layer": "Breyta þekju fitjunnar",
    "Edit properties in a table": "Breyta eigindum í töflu",
    "Edit the title of the map": "Breyta titli landakortsins",
    "Edit this feature": "Breyta þessari fitju",
    "Edit": "Breyta",
    "Embed and link options": "Embed and link options",
    "Embed the map": "Setja landakortið inn á vefsíðu",
    "Emoji & Character": "Tákn og stafir",
    "Empty": "Tómt",
    "Equidistant": "Equidistant",
    "Error in the overlay URL": "Villa í slóð yfirlagsþekju",
    "Error in the tilelayer URL": "Villa í slóð kortatíglaþekju",
    "Exit Fullscreen": "Hætta í skjáfylli",
    "expanded": "útliðað",
    "Extract shape to separate feature": "Flytja lögun í aðskilda fitju",
    "Feature identifier key": "Auðkennislykill fitju",
    "Feature properties": "Eiginleikar fitju",
    "Fetch data each time map view changes.": "Sækja gögn í hvert skipti sem kortasýn breytist",
    "fill color": "fyllilitur",
    "fill opacity": "ógegnsæi fyllingar",
    "fill": "fylling",
    "Fit all data": "Fit all data",
    "Format": "Snið",
    "From zoom": "Úr aðdráttarstigi",
    "full backup": "full backup",
    "GeoRSS (only link)": "GeoRSS (aðeins tengill)",
    "GeoRSS (title + image)": "GeoRSS (titill + mynd)",
    "Go to \"{coords}\"": "Fara á \"{coords}\"",
    "Go to the homepage": "Fara á heimasíðuna",
    "Go to «{feature}»": "Fara á «{feature}»",
    "Heatmap intensity property": "Styrkeigindi fyrir hitakort",
    "Heatmap radius": "Radíus hitakorts",
    "Heatmap": "Hitakort",
    "height": "hæð",
    "Help": "Hjálp",
    "hidden": "falið",
    "Hide controls": "Fela hnappa",
    "Home": "Heim",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Hve mikið eigi að einfalda fjölpunktalínu á hverju aðdráttarstigi (meira = betri afköst og mýkra útlit, minna = nákvæmara)",
    "icon opacity": "ógegnsæi tákns",
    "Icon shape": "Lögun táknmyndar",
    "Icon symbol": "Myndtákn",
    "If false, the polygon or line will act as a part of the underlying map.": "If false, the polygon or line will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "Iframe með sérsniðinni hæð (í mynddílum/px): {{{https://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "Iframe með sérsniðinni hæð og breidd (í mynddílum/px): {{{https://iframe.url.com|height*width}}}",
    "iframe": "iFrame",
    "Iframe: {{{https://iframe.url.com}}}": "Iframe: {{{https://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Mynd með sérsniðinni breidd (í mynddílum): {{https://image.url.com|width}}",
    "Image: {{https://image.url.com}}": "Mynd: {{https://image.url.com}}",
    "Import data": "Flytja inn gögn",
    "Import in a new layer": "Flytja inn í nýja þekju",
    "Imports all umap data, including layers and settings.": "Flytur inn öll umap-gögn, þar með talin þekjur og stillingar.",
    "Include full screen link?": "Hafa með tengil á að fylla skjá?",
    "Inherit": "Erfa",
    "inherit": "erfa",
    "Interaction options": "Valkostir gagnvirkni",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "Ógild umap-gögn í {filename}",
    "Invalid umap data": "Ógild umap-gögn",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Halda fyrirliggjandi sýnilegum þekjum",
    "kilometers": "kílómetrar",
    "km": "km",
    "Label direction": "Stefna skýringar",
    "Label key": "Lykill skýringar",
    "Labels are clickable": "Hægt er að smella á skýringar",
    "Latest feature": "Síðasta fitja",
    "Latitude": "Breiddargráða",
    "Layer properties": "Eiginleikar þekju",
    "Layer": "Þekja",
    "Licence": "Notkunarleyfi",
    "licence": "notkunarleyfi",
    "Limit bounds": "Mörk útjaðars",
    "Link to view the map": "Tengill til að skoða kortið",
    "Link to…": "Tengja við…",
    "Link with text: [[https://example.com|text of the link]]": "Tengill með texta: [[https://example.com|texti tengils]]",
    "Long credits": "Lengra um framlög",
    "Longitude": "Lengdargráða",
    "Manage layers": "Sýsla með þekjur",
    "Manual": "Manual",
    "Map background credits": "Þakkir vegna bakgrunnsmyndar:",
    "Map has been attached to your account": "Kortið hefur verið tengt við notandaaðganginn þinn",
    "Map has been saved!": "Landakortið hefur verið vistað!",
    "Map has been starred": "Landakortið hefur verið stjörnumerkt",
    "Map has been unstarred": "Stjörnumerking hefur verið tekin af landakortinu",
    "Map user content has been published under licence": "Kortagögn notandans eru gefin út með notkunarleyfinu",
    "Map's editors": "Ritstjórar korts",
    "Map's owner": "Eigandi korts",
    "max East": "Hám. austur",
    "max North": "Hám. norður",
    "max South": "Hám. suður",
    "max West": "Hám. vestur",
    "max zoom": "Hám. aðdráttur",
    "Measure distances": "Mæla vegalengdir",
    "Merge lines": "Sameina línur",
    "mi": "mi",
    "miles": "mílur",
    "min zoom": "lágm. aðdráttur",
    "More controls": "Fleiri hnappar",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Verður að vera gilt CSS-gildi (t.d.: DarkBlue eða #123456)",
    "name": "heiti",
    "nautical miles": "sjómílur",
    "never": "aldrei",
    "new window": "nýr gluggi",
    "next": "næsta",
    "NM": "Sjómílur",
    "No cache": "Ekkert biðminni",
    "No licence has been set": "Ekkert notkunarleyfi hefur verið sett",
    "No results": "Engar niðurstöður",
    "no": "nei",
    "No.": "Nr.",
    "None": "Ekkert",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "On the bottom": "Neðst",
    "On the left": "Vinstra megin",
    "On the right": "Hægra megin",
    "On the top": "Efst",
    "Only visible layers' data": "Aðeins gögn sýnilegrar þekju",
    "opacity": "ógegnsæi",
    "Opacity": "Ógegnsæi",
    "Open current feature on load": "Opna fyrirliggjandi fitju við innhleðslu",
    "Open link in…": "Opna tengil í…",
    "Open share & download panel": "Opna deilingar- og niðurhalsspjald",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Opna umfang þessa korts í kortavinnsluforriti til að gefa nákvæmari kortagögn til OpenStreetMap",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Valfrjálst styrkeigindi fyrir hitakort",
    "Optional. Same as color if not set.": "Valfrjálst. Sama og litur ef ekkert er skilgreint.",
    "Optional.": "Valfrjálst.",
    "Override clustering radius (default 80)": "Nota annan radíus klösunar (sjálfgefið 80)",
    "Override heatmap radius (default 25)": "Nota annan radíus hitakorts (sjálfgefið 25)",
    "parent window": "yfirgluggi",
    "Paste your data here": "Límdu gögnin þín hér",
    "Permalink": "Fastur tengill",
    "Permanent credits background": "Viðvarandi bakgrunnur framlaga",
    "Permanent credits": "Viðvarandi framlög",
    "Please be sure the licence is compliant with your use.": "Gakktu úr skugga um að notkunarleyfið samsvari notkunasviði þínu.",
    "Please choose a format": "Veldu snið",
    "Please enter the name of the property": "Settu inn heiti á eigindið",
    "Please save the map first": "Vistaðu fyrst kortið",
    "Popup (large)": "Sprettgluggi (stór)",
    "Popup content style": "Stíll efnis í sprettglugga",
    "Popup content template": "Sniðmát efnis í sprettglugga",
    "Popup shape": "Lögun sprettglugga",
    "Popup": "Sprettgluggi",
    "Powered by uMap": "Keyrt með uMap",
    "previous": "fyrra",
    "Problem in the response": "Vandamál í svarinu",
    "Properties imported:": "Innflutt eigindi:",
    "Provide an URL here": "Gefðu hér upp URL-slóð",
    "Proxy request": "Beiðni frá milliþjóni",
    "Quantiles": "Quantiles",
    "Recent": "Nýlegt",
    "Remote data": "Fjartengd gögn",
    "Replace layer content": "Skipta út innihaldi þekjunnar",
    "Restore this version": "Endurheimta þessa útgáfu",
    "Save current edits": "Vista fyrirliggjandi breytingar",
    "Save map": "Vista kort",
    "Save": "Vista",
    "Saved center and zoom": "Vistaði miðju og aðdrátt",
    "Search location": "Leita að staðsetningu",
    "Search": "Leita",
    "Secret edit link:": "Leynilegur breytingatengill:",
    "See full screen": "Fylla skjáinn",
    "See on OpenStreetMap": "Skoða á OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Settu þetta sem ósatt til að fela þessa þekju úr skyggnusýningu, gagnavafranum, sprettleiðsögn…",
    "settings": "stillingar",
    "Shape properties": "Eiginleikar lögunar",
    "Share and download": "Deila og sækja",
    "Share this link to open a customized map view": "Share this link to open a customized map view",
    "Short credits": "Stutt um framlög",
    "Short link": "Short link",
    "Show this layer in the caption": "Show this layer in the caption",
    "Show/hide layer": "Birta/Fela þekju",
    "Side panel": "Hliðarspjald",
    "Simple link: [[https://example.com]]": "Einfaldur tengill: [[https://example.com]]",
    "Simplify": "Einfalda",
    "Skipping unknown geometry.type: {type}": "Sleppi óþekktu geometry.type: {type}",
    "Slideshow": "Skyggnusýning",
    "Sort key": "Röðunarlykill",
    "Split line": "Skipta línu",
    "Star this map": "Stjörnumerkja þetta landakort",
    "Start a hole here": "Byrja holu hér",
    "Start slideshow": "Hefja skyggnusýningu",
    "Stop editing": "Hætta breytingum",
    "Stop slideshow": "Stöðva skyggnusýningu",
    "Street": "Gata",
    "stroke": "strik",
    "Supported scheme": "Stutt skema",
    "Supported variables that will be dynamically replaced": "Studdar breytur sem verður skipt út eftir þörfum",
    "Symbol": "Tákn",
    "Table": "Tafla",
    "Text color for the cluster label": "Litur á texta fyrir skýringu á klasa",
    "Text formatting": "Snið á texta",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "Heiti eigindisins sem á að nota sem auðkenni á fitju.",
    "The zoom and center have been modified.": "Aðdrætti og miðjun hefur verið breytt.",
    "TMS format": "TMS-snið",
    "To use if remote server doesn't allow cross domain (slower)": "Nota ef fjartengdur þjónn leyfir ekki millivísanir léna (hægvirkara)",
    "To zoom": "Í aðdrátt",
    "Toggle edit mode (⇧+Click)": "Víxla breytingaham af/á (⇧+Smella)",
    "Toggle edit mode": "Víxla breytingaham af/á",
    "Transfer shape to edited feature": "Flytja lögun í breyttu fitjuna",
    "Transform to lines": "Umbreyta í línur",
    "Transform to polygon": "Umbreyta í fláka/marghyrning",
    "Type a place name or coordinates": "Skrifaðu staðarheiti eða hnit",
    "Type char or paste emoji": "Type char or paste emoji",
    "Type of layer": "Tegund þekju",
    "Unable to detect format of file {filename}": "Tókst ekki að ákvarða sniðið á skránni {filename}",
    "Untitled layer": "Ónefnd þekja",
    "Untitled map": "Ónefnt landakort",
    "Update permissions and editors": "Uppfæra heimildir og ritstjóra",
    "Update permissions": "Uppfæra heimildir",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "Url": "Slóð",
    "URL": "Vefslóð",
    "Use current bounds": "Nota fyrirliggjandi útjaðar",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Notaðu frátökutákn með eigindum fitja innan sviga, t.d. &#123;nafn&#125;, þeim verður skipt út eftir þörfum fyrir samsvarandi gildi.",
    "User content credits": "Framlög notanda á efni",
    "User interface options": "Valkostir notendaviðmóts",
    "User location": "Staðsetning notanda",
    "Verify remote URL": "Verify remote URL",
    "Versions": "Útgáfur",
    "View Fullscreen": "Fylla skjáinn",
    "View": "Skoða",
    "Visibility: {status}": "Sýnileiki: {status}",
    "weight": "þykkt",
    "Where do we go from here?": "Hvert förum við héðan?",
    "Whether to display or not polygons paths.": "Hvort birta eigi ferla fláka/marghyrninga.",
    "Whether to fill polygons with color.": "Hvort eigi að fylla fláka með lit.",
    "Who can edit \"{layer}\"": "Hver getur breytt \"{layer}\"",
    "Who can edit": "Hverjir geta breytt",
    "Who can view": "Hverjir geta skoðað",
    "width": "breidd",
    "Will be displayed in the bottom right corner of the map": "Verður birt niðri í hægra horni kortsins",
    "Will be permanently visible in the bottom left corner of the map": "Verður birt varanlega niðri í vinstra horni kortsins",
    "Will be visible in the caption of the map": "Verður sýnilegt í skýringatexta kortsins",
    "yes": "já",
    "Zoom in": "Renna að",
    "Zoom level for automatic zooms": "Aðdráttarstig fyrir sjálfvirkan aðdrátt",
    "Zoom out": "Renna frá",
    "Zoom to layer extent": "Renna að útjöðrum þekju",
    "Zoom to the next": "Aðdráttur að næsta",
    "Zoom to the previous": "Aðdráttur á fyrra",
    "Zoom to this feature": "Aðdráttur að þessari fitju",
    "{area}&#8239;acres": "{area} ekrur",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} villur við innflutning: {message}",
    "{delay} seconds": "{delay} sekúndur",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} mílur",
    "{distance}&#8239;NM": "{distance} sjómílur",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Breyta heiti korts og skýringum",
    "Map advanced properties": "Map advanced properties",
    "Edit map details": "Breyta nánari upplýsingum korts",
    "Back to browser": "Til baka í vafra",
    "Toggle size": "Toggle size",
    "Display the caption control": "Display the caption control",
    "<empty value>": "<empty value>",
    "Min": "Lágm",
    "Max": "Hám",
    "From": "Frá",
    "Until": "Til",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Breyta á OpenStreetMap",
    "Back to layers": "Til baka í þekjur",
    "Filters": "Síur",
    "Comma separated list of properties to use when filtering features by text input": "Kommu-aðgreindur listi yfir eigindi sem notaður er við síun fitja með textainnslætti",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Leita í lyklum",
    "Filters keys": "Filters keys",
    "Filter data": "Sía gögn",
    "Search map features…": "Search map features…",
    "Reset all": "Frumstilla allt",
    "Open browser": "Opna vafra",
    "Open caption": "Open caption",
    "Your map has been created with an anonymous account!": "Your map has been created with an anonymous account!",
    "Real-time collaboration": "Samstarf í rauntíma",
    "Cannot parse data": "Cannot parse data",
    "Start typing...": "Byrjaðu að skrifa...",
    "No result": "Engar niðurstöður",
    "Data browser": "Gagnavafri",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "lykill (t.d. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "More info about Overpass syntax",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Veldu gögn",
    "Choose the format": "Choose the format",
    "Choose the layer": "Veldu þekjuna",
    "Layer name": "Heiti þekju",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Afrita inn í þekjuna",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Skilyrði",
    "key=value or key!=value": "key=value or key!=value",
    "Are you sure you want to delete this rule?": "Are you sure you want to delete this rule?",
    "empty rule": "empty rule",
    "Conditional style rules": "Conditional style rules",
    "Add rule": "Add rule",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: layers",
    "Browser: filters": "Browser: filters",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Afritað!",
    "Choose a dataset": "Choose a dataset",
    "Choose this dataset": "Choose this dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Choose a theme",
    "Choose this data": "Choose this data",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Expression",
    "Geometry mode": "Geometry mode",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Data successfully imported!",
    "Clear data": "Clear data",
    "Remove layers": "Fjarlægja þekjur",
    "Categorized": "Categorized",
    "Alphabetical": "Alphabetical",
    "Category property": "Category property",
    "Color palette": "Litaspjald",
    "Categories": "Flokkar",
    "Comma separated list of categories.": "Comma separated list of categories.",
    "Categories mode": "Categories mode",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Rename this column",
    "Delete this column": "Delete this column",
    "Name “{name}” should not contain a dot.": "Name “{name}” should not contain a dot.",
    "This name already exists: “{name}”": "This name already exists: “{name}”",
    "Delete selected rows": "Delete selected rows",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Expression is empty",
    "OK": "Í lagi",
    "Cancel": "Hætta við",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control",
    "Copy as GeoJSON": "Copy as GeoJSON",
    "Please zoom in to edit the geometry": "Please zoom in to edit the geometry",
    "New map": "Nýtt landakort",
    "My maps": "Landakortin mín",
    "My teams": "Teymin mín",
    "My profile": "Sniðið mitt",
    "Type new owner's username": "Type new owner's username",
    "Type editor's username": "Type editor's username",
    "Map": "Kort",
    "Manage collaborators": "Manage collaborators",
    "show/hide all layers": "birta/fela allar þekjur",
    "zoom to data extent": "zoom to data extent",
    "download visible data": "download visible data",
    "Import helpers": "Import helpers",
    "Import helpers will fill the URL field for you.": "Import helpers will fill the URL field for you.",
    "Wikipedia": "Wikipedia",
    "Save draft": "Vista drög",
    "No data has been found for import": "No data has been found for import",
    "Successfully imported {count} feature(s)": "Successfully imported {count} feature(s)",
    "Disconnected": "Aftengt",
    "You must be logged in": "You must be logged in",
    "on hover": "on hover",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "Cannot load remote data for layer \"{layer}\" with url \"{url}\"",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"",
    "Import failed: invalid data": "Import failed: invalid data",
    "Anonymous": "Nafnlaus",
    "created at {date}": "created at {date}",
    "modified at {date}": "modified at {date}",
    "Default zoom": "Sjálfgefinn aðdráttur",
    "Default latitude": "Sjálfgefin breiddargráða",
    "Default longitude": "Sjálfgefin lengdargráða",
    "Edit map default view": "Edit map default view",
    "Use current center and zoom": "Nota þessa miðju og aðdrátt",
    "Layer permalink": "Fastur tengill þekju",
    "Back to home": "Back to home",
    "Home logo": "Home logo",
    "Add this geometry to my map": "Add this geometry to my map",
    "Add this place to my map": "Add this place to my map",
    "Cancel last edit": "Cancel last edit",
    "Redo last edit": "Redo last edit",
    "Links": "Links",
    "Images": "Images",
    "Iframes": "Iframes",
    "Tags": "Tags",
    "Geocode": "Geocode",
    "Display the back to home icon": "Display the back to home icon",
    "Do you want to display layer switcher in caption bar?": "Do you want to display layer switcher in caption bar?",
    "Simplify all geometries to points": "Simplify all geometries to points",
    "Back to list": "Back to list",
    "Toggle rule": "Toggle rule",
    "Delete rule": "Delete rule",
    "Cannot save layer, please try again in a few minutes.": "Cannot save layer, please try again in a few minutes.",
    "Activate collaborative live editing on this map. Other users must reload the map after changing this setting.": "Activate collaborative live editing on this map. Other users must reload the map after changing this setting.",
    "More help resources": "More help resources",
    "This map is a template": "This map is a template",
    "Add text along path": "Add text along path",
    "Text color": "Text color",
    "Text offset": "Text offset",
    "Text position": "Text position",
    "start": "start",
    "center": "center",
    "end": "end",
    "Text repeat": "Text repeat",
    "Text rotate": "Text rotate",
    "Text size": "Text size",
    "Load map template": "Load map template",
    "My templates": "My templates",
    "From staff": "From staff",
    "From community": "From community",
    "You must select a template.": "You must select a template.",
    "Line decoration": "Line decoration",
    "Reuse this template": "Reuse this template",
    "Create a new map using this template": "Create a new map using this template",
    "Save template": "Save template",
    "Load template": "Load template",
    "Loading a template will apply predefined styles and settings to your map": "Loading a template will apply predefined styles and settings to your map",
    "Load template with data": "Load template with data",
    "You have no registered template yet. You can add one by creating a new map and flagging it as \"template\".": "You have no registered template yet. You can add one by creating a new map and flagging it as \"template\".",
    "There is no recommended template yet. Recommended templates are the ones starred by uMap administrators.": "There is no recommended template yet. Recommended templates are the ones starred by uMap administrators.",
    "There is no public template yet.": "There is no public template yet.",
    "Explore": "Explore",
    "Import data from public open data portals": "Import data from public open data portals",
    "Choose a portal": "Choose a portal",
    "Limit results to current map view": "Limit results to current map view",
    "Please choose an instance first.": "Please choose an instance first.",
    "No geo column found: must be either `lat(itude)` and `lon(gitude)` or `geom(etry)`.": "No geo column found: must be either `lat(itude)` and `lon(gitude)` or `geom(etry)`.",
    "Add a new field": "Add a new field",
    "Are you sure you want to delete this field on all the features?": "Are you sure you want to delete this field on all the features?",
    "Please enter the new name of this field": "Please enter the new name of this field",
    "Cannot process MultiPoint": "Cannot process MultiPoint",
    "Manage Fields": "Manage Fields",
    "Rename this field": "Rename this field",
    "Delete this field": "Delete this field",
    "Double click to edit the name": "Double click to edit the name",
    "Print map": "Print map",
    "Choose a format": "Choose a format",
    "Scale map": "Scale map",
    "portrait": "portrait",
    "landscape": "landscape",
    "Print": "Print",
    "Preparing the print…": "Preparing the print…",
    "Large Circle": "Large Circle",
    "Icon size": "Icon size",
    "Will only affect raw and large circle icons.": "Will only affect raw and large circle icons.",
    "Route": "Route",
    "Display the print control": "Display the print control",
    "Compute isochrone from here": "Compute isochrone from here",
    "Route settings": "Route settings",
    "Transform to regular line": "Transform to regular line",
    "Transform to route": "Transform to route",
    "Restore route": "Restore route",
    "Compute elevation": "Compute elevation",
    "Profile": "Profile",
    "Compute elevations": "Compute elevations",
    "Route preference": "Route preference",
    "Compute route": "Compute route",
    "Walking": "Walking",
    "Hiking": "Hiking",
    "By car": "By car",
    "Cycling": "Cycling",
    "Wheelchair": "Wheelchair",
    "Recommended": "Recommended",
    "Fastest": "Fastest",
    "Shortest": "Shortest",
    "Max time (in minutes)": "Max time (in minutes)",
    "Number of lines": "Number of lines",
    "Distance:": "Distance:",
    "Gain:": "Gain:",
    "Loss:": "Loss:",
    "Altitude:": "Altitude:",
    "Right-click to edit": "Right-click to edit",
    "Draw along routes": "Draw along routes"
}
L.registerLocale("is", locale)
L.setLocale("is")
